@@ -3,5 +3,5 @@ from AnyDateTimeAttr import AnyDateTimeAttr
 
 class DateAttr(AnyDateTimeAttr):
 
-	def __init__(self, dict):
-		AnyDateTimeAttr.__init__(self, dict)
+    def __init__(self, attr):
+        AnyDateTimeAttr.__init__(self, attr)
